#!/usr/local/bin/python2.6
# -*- coding: utf-8 -*-

"""udvdshift : Like srtshidt, but for MicroDVD format

USAGE
  udvdshift xDDDD infile > outfile

OPTIONS
  x    : + or - ; + shifts to the end
  DDDD : the amount of frames to shift. You'll have to know/guess the framerate
         and multiply by the amount of desired seconds to obtain this number.
         e.g. 10 seconds with 25 frames per second (fps) => 10*25 = 250 frames

EXAMPLES
  python udvdshift.py -290 "Il Mostro (1994).srt" > "Il Mostro.sub"
  python udvdshift.py -290 -- < "Il Mostro (1994).srt" > "Il Mostro.sub"

NOTE
  Beware not to use '|' to pipe commands, since it doesn't transmit the EOF

TODO
  Maybe don't permit to decrement under zero ?

LINKS
  MicroDVD's offical website : http://www.tiasoft.de/mdvdp/index.htm
"""

import sys		# sys args
import re		# regular expressions



def shift( line, op, amount ):

	match = re.match(u"{(\d+)}{(\d+)}(.*)",line)
	start = int(match.groups()[0])
	duration = int(match.groups()[1]) - start
	text = match.groups()[2]
	if op == "-":
		start = start - amount
	else:
		start = start + amount

	return "{%d}{%d}%s" % ( start , start + duration, text )



def main(argv=None):

	if argv is None:
		argv = sys.argv

	if len(argv) < 3:
		sys.exit(__doc__+"\nNot enough arguments")

	try:
		params = re.match(u"([^\d]*)(\d+)",argv[1])
		op = params.groups()[0]
		amount = int(params.groups()[1])
	except e:
		sys.exit(__doc__+"\nIrregular expression !\n"+repr(e))

	# A. reads from the standard input
	fin = None
	if argv[2] == "--":
		line = sys.stdin.readline()
		while len(line) > 0:
			print shift(line,op,amount)
			line = sys.stdin.readline()
	# B. reads from a file
	else:
		fin = open(argv[2])
		for line in fin:
			print shift(line,op,amount)



if __name__ == "__main__":

	sys.exit(main())


